%------------------------------------------------------------
% MAIN PROGRAM! All materiel properties and constants used in 
%the simulation is listed in the string Const. Three current 
%densities are used, 200, 500, 1000 and 5000 A/m^2 which gives 4 
%sets of results.
%------------------------------------------------------------
function Master3()

    clc;
    clear all;
    close all;
    global Const;
    
    phi = [];
    Jqja = [];
    Jqjc = [];
    Jwaj = [];
    Jwcj = [];

    j = [200 500 1000 5000];           
    %[A/m^2]       % Current density
    
    for i = 1:length(j)
        Const.j = j(i);               
        
        %General constants used in the simulation
        
        Const.R = 8.314;             
        %[J/(K mol) ] % universal gas constant
        Const.F = 96500;             
        %[C/mol     ] % Faradays constant
        Const.Tq = 298;              
        %[K          ] % reference temperature
        Const.p = 1.013e5;           
        %[Pa         ] % Standard pressure

        
        %Materiel properties of the Nafion membrane
        
        Const.dm = 192E-6;           
        %[m          ] % membrane thickness
        Const.Dm = 8.05E-8;          
        %[ m^2/s     ] % membrane diffusion coefficient
        Const.rodry = 1640;          
        %[kg/m^3     ] % membrane density dry
        Const.Mm = 1.1;              
        %[kg/mol     ] % membrane molar mass
        Const.Mw = 0.018;            
        %[kg/mol     ] % water molar mass
        Const.twm = 1.2;             
        %[Unitless   ] % Transport number of water
     
        
        %Materiel properties of the anode and cathode backing

        Const.ds = 246E-6;           
        %[m          ] % Sigracet thickness
        Const.LsAA = 0.42;           
        %[ W/(K m)   ] % Sigracet 10AA conductivity
        %Const.LsAA = 0.33;          
        %[ W/(K m)   ] % Sigracet 10BA conductivity
        Const.rac = 1e-4;            
        %[ ohm m) ] %Electrical resistance in anode/cathode
        Const.Dwh = 5e-5;             
        %[ m^2/s) ] %Binar diffusion of hydrogen and water
        Const.DON = 5e-5;         
        %[ m^2/s) ] %Binar diffusion of oxygen and nitrogen
        Const.xO20 = 0.21;
        %[ unitless ] %Mole fraction of oxygen at the end of 
        % the cathode backing
        
        
        %Materiel properties of the Anode and Cathode surface

        Const.Ls = 1710;            
        %[ W/(K m^2) ] % Surface 10AA conductivity
        %Const.Ls = 1300;            
        %[ W/(K m^2) ] % Surface 10BA conductivity
        Const.rs = 7.2e-6;             
        %[ohm m^2]  %Electrical resistance
        Const.tad = 0;                    
        %[Unitless   ] % Combined transport number of water and
        % hydrogen in the anode backing
       


        %%Fluxes%%

        Const.j0 = 2.5e-3;                    
        %[A/m^2]       % Exchange current density   
        Const.JH2 = Const.j/(2*Const.F);      
        %[kg/m^s s]    % Hydrogen gas flux
        Const.JO2 = -Const.j/(4*Const.F);     
        %[kg/m^s s]    % Oxygen gas flux

        
        %%Entalphies and entropies%%

        Const.Hwm = -285e3;             
        %[J/mol]      %Entalphy for liquid water
        Const.Swm = 70;                 
        %[J/K mol]    %Entropy for liquid water
        Const.cpw = 75;                 
        %[J/K mol]    %Cp for liquid water
        Const.Hwgas = -242e3;           
        %[J/mol]      %Entalphy for gas water
        Const.Swgas = 189;              
        %[J/K mol]    %Entropy for gas water
        Const.cpwgas = 34;              
        %[J/K mol]    %Cp for gas water
        Const.Sh = 192;                  
        %[J/K mol]    %Entropy for protons (H+)
        Const.cpH = 21;                 
        %[J/K mol]    %Cp for protons (H+)
        Const.Se = -2;                  
        %[J/K mol]    %Entropy for electrons
        Const.Sh2 = 131;                
        %[J/K mol]    %Entropy for H2 (g)
        Const.cph2 = 29;                
        %[J/K mol]    %Cp for H2 (g)
        Const.So2 = 205;                
        %[J/K mol]    %Entropy for O2 (g)
        Const.cpo2 = 29;                
        %[J/K mol]    %Cp for O2 (g)
        Const.Hwvap = Const.Hwgas-Const.Hwm;   
        %[J/K mol]    %Vaporization enthalpy of water


        %Starting parameters
        
        Const.T0 = 330;
        %[K]    %Temperature of the start at the anode backing
        Jq0 = 1000;
        %[W/m^2]    %Initial heat flux guess

        options = optimset('Display','iter');

        
        %Starting the simulation
        
        [X, FVAL, EXITFLAG] = fsolve('Transport', Jq0, options, 0);

        [res,phic, Jqa, Jqc, Jwa, Jwc, Xvector, Yvector] = Transport(X,1);
        
        
         %Making the vectors for plotting the profiles in the same plot
         
         phi = [phi, phic];        
         Jqa = Jqa/(Const.j/Const.F);     
         Jqc = Jqc/(Const.j/Const.F);
         Jwaj1 = Jwa/(Const.j/Const.F);
         Jwcj1 = Jwc/(Const.j/Const.F);
         Jqja = [Jqja, Jqa];
         Jqjc = [Jqjc, Jqc];                 
         Jwaj = [Jwaj, Jwaj1]; 
         Jwcj = [Jwcj, Jwcj1];
         
         Temp(:,i) = Yvector(:,1);
         phi2(:,i) = Yvector(:,2);
         x(:,i) = Yvector(:,3);
         Jq(:,i) = Yvector(:,4);
         S(:,i) = Yvector(:,5);
         
         Thickness(:,i) = Xvector(:,1);
               
                  
    end   
    
    
    %Plotting the Temperatures
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Thickness(:,1), Temp(:,1));
        myfit2 = line(Thickness(:,2), Temp(:,2));
        myfit3 = line(Thickness(:,3), Temp(:,3));
        myfit4 = line(Thickness(:,4), Temp(:,4));
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{T} \rm{/ K}'                );
        xlim([0 Thickness(end,end)])
        ylim([Temp(end,4) 340])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'          );
        set(myfit3                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'           );
        set(myfit4                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'           );



        hLegend = legend( ...
       [myfit1, myfit2, myfit3, myfit4], ...
       'Current density of 200 \rm{A/m^{2}}' , ...
       'Current density of 500 \rm{A/m^{2}}' , ...
       'Current density of 1000 \rm{A/m^{2}}' , ...
       'Current density of 5000 \rm{A/m^{2}}' , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend             , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
     %Plotting the phi
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Thickness(:,1), phi2(:,1));
        myfit2 = line(Thickness(:,2), phi2(:,2));
        myfit3 = line(Thickness(:,3), phi2(:,3));
        myfit4 = line(Thickness(:,4), phi2(:,4));
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{\phi} \rm{/ V}'                );
        xlim([0 Thickness(end,end)])
        ylim([-0.6 0.8])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'            );
        set(myfit3                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'            );
        set(myfit4                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'            );



        hLegend = legend( ...
       [myfit1, myfit2, myfit3, myfit4], ...
       'Current density of 200 \rm{A/m^{2}}' , ...
       'Current density of 500 \rm{A/m^{2}}' , ...
       'Current density of 1000 \rm{A/m^{2}}' , ...
       'Current density of 5000 \rm{A/m^{2}}' , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend             , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
         %Plotting the mole fraction
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line([Thickness(1,1) Thickness(40,1)], [x(1,1) x(40,1)]);
        myfit2 = line([Thickness(1,2) Thickness(40,2)], [x(1,1) x(40,2)]);
        myfit3 = line([Thickness(1,3) Thickness(40,3)], [x(1,1) x(40,3)]);
        myfit4 = line([Thickness(1,4) Thickness(40,4)], [x(1,1) x(40,4)]);
        myfit5 = line([Thickness(41,1) Thickness(end,1)], [x(41,1) x(end,1)]);
        myfit6 = line([Thickness(41,2) Thickness(end,2)], [x(41,1) x(end,2)]);
        myfit7 = line([Thickness(41,3) Thickness(end,3)], [x(41,1) x(end,3)]);
        myfit8 = line([Thickness(41,4) Thickness(end,4)], [x(41,1) x(end,4)]);
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{x} '                );
        xlim([0 Thickness(end,end)])
        ylim([0.11 0.21])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'            );
        set(myfit3                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'            );
        set(myfit4                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'            );
        set(myfit5                          , ...
        'LineWidth'       , 4           );
        set(myfit6                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'            );
        set(myfit7                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'            );
        set(myfit8                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'            );



        hLegend = legend( ...
       [myfit1, myfit2, myfit3, myfit4], ...
       'Current density of 200 \rm{A/m^{2}}' , ...
       'Current density of 500 \rm{A/m^{2}}' , ...
       'Current density of 1000 \rm{A/m^{2}}' , ...
       'Current density of 5000 \rm{A/m^{2}}' , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend              , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
        %Plotting the measurable heat flux
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Thickness(:,1), Jq(:,1));
        myfit2 = line(Thickness(:,2), Jq(:,2));
        myfit3 = line(Thickness(:,3), Jq(:,3));
        myfit4 = line(Thickness(:,4), Jq(:,4));
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{J_{q}^{`}} \rm{/ W/m^{2}}'                );
        xlim([0 Thickness(end,end)])
        ylim([-5000 13000])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'            );
        set(myfit3                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'            );
        set(myfit4                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'            );



        hLegend = legend( ...
       [myfit1, myfit2, myfit3, myfit4], ...
       'Current density of 200 \rm{A/m^{2}}' , ...
       'Current density of 500 \rm{A/m^{2}}' , ...
       'Current density of 1000 \rm{A/m^{2}}' , ...
       'Current density of 5000 \rm{A/m^{2}}' , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend             , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );

    
        %Plotting entropy production
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Thickness(:,1), S(:,1));
        myfit2 = line(Thickness(:,2), S(:,2));
        myfit3 = line(Thickness(:,3), S(:,3));
        myfit4 = line(Thickness(:,4), S(:,4));
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{\sigma} \rm{/ W/m^{2}K}'                );
        xlim([0 Thickness(end,end)])
        ylim([0 25])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4             , ...
        'Color'           , 'r'            );
        set(myfit3                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'g'            );
        set(myfit4                          , ...
        'LineWidth'       , 4           , ...
        'Color'           , 'k'            );



        hLegend = legend( ...
       [myfit1, myfit2, myfit3, myfit4], ...
       'Current density of 200 \rm{A/m^{2}}' , ...
       'Current density of 500 \rm{A/m^{2}}' , ...
       'Current density of 1000 \rm{A/m^{2}}' , ...
       'Current density of 5000 \rm{A/m^{2}}' , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend              , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
    
        %Plotting the polarization curve
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(j, phi);
        myfit2 = line([0 j(end)],...
            [1.17 1.17]);
        hXLabel = xlabel('\it{j} \rm{/ A/m^{2}}'                     );
        hYLabel = ylabel('\it{E_{cell}} \rm{/ V}'                );
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4               ,...
        'Color'           , 'r'            );



        hLegend = legend( ...
       [myfit1, myfit2], ...
       'Cell potential from simulation ' , ...
       'Theoretical cell potential in the reversible limit'                , ...
      'location', 'NorthWest' );   
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set(hLegend             , ...
         'FontSize'   , 30           );
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
       
    
        %Plotting the heat flux divided by j/F
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(j, Jqja);
        myfit2 = [];
        hXLabel = xlabel('\it{j} \rm{/ A/m^{2}}'                     );
        hYLabel = ylabel('\it{J_{q}^{`,a}/(j/F)} \rm{/ J/mol}'                );
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
    
    
       %Plotting the heat flux divided by j/F
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(j, Jqjc);
        myfit2 = [];
        hXLabel = xlabel('\it{j} \rm{/ A/m^{2}}'                     );
        hYLabel = ylabel('\it{J_{q}^{`,c}/(j/F)} \rm{/ J/mol}'                );
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );

      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
        %Plotting the mass flux divided by j/F
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(j, Jwaj);
        myfit2 = [];
        hXLabel = xlabel('\it{j} \rm{/ A/m^{2}}'                     );
        hYLabel = ylabel('\it{J_{w}^{a}/(j/F)}'                );
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
        %Plotting the mass flux divided by j/F
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(j, Jwcj);
        myfit2 = [];
        hXLabel = xlabel('\it{j} \rm{/ A/m^{2}}'                     );
        hYLabel = ylabel('\it{J_{w}^{c}/(j/F)}'                );
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );


      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );

end