%------------------------------------------------------------
% Main subroutine that calls on the smaller subroutine of
% each segment in the fuel cell. Plotting the profiles
% in the end of the code.
%------------------------------------------------------------

function [res,phic,Jqa,Jqc,Jwa,Jwc,Xvector,Yvector] = Transport(Jqa, plot)


    global Const;
    
    Jqa0 = Jqa;
    
    %Finding the correct water flux for the given heat flux
    [Jw0, res, EXITFLAG] = fzero('Jw',0,[],Jqa0);
    
    if EXITFLAG ~= 1
        error('No appropriate value of Jw found')
    end
    
    Const.Jwm = Jw0;
    
    Const.Jwa = Const.Jwm;
    Jwa = Const.Jwa;
    %[kg/m^s s]    % Water flux in anode and membrane
    Const.Jwc = Const.Jwa + Const.j/(2*Const.F);
    Jwc = Const.Jwc;
    %[kg/m^s s]    % Water flux in catode
    Const.twc = ((Const.Jwa/(Const.j/Const.F))+0.5);
    twc = Const.twc;
    %[Unitless]    % Transport number for water in the cathode
    
    %Calculating the saturation prsesure and mole fraction of 
    %water at the start of the anode backing
    pw = ps(Const.T0);
    xw0 = pw/(Const.p);
    
    %Definition of the half cell potential of hydrogen and
    %zero entropy at the start of the anode backing
    phi0 = 0;                                    
    s0 = 0;
    
    %Boundary conditions at the start of the anode backing
    ya0 = [Const.T0, phi0, xw0, Jqa0, s0];
    
    %Length of the different segments in the fuel cell
    xanode = linspace(0, Const.ds, 40);
    xmembrane = linspace(Const.ds, Const.ds+Const.dm, 40);
    xcathode = linspace(Const.ds+Const.dm,Const.ds*2+...
        Const.dm,40);
    
    %Calculating the variations of the unknown parameters in the 
    %anode backing
    [Xanode, Yanode] = ode15s('anode',xanode,ya0);
  
    %Calculating the jumps of the unknown parameters in the 
    %anode surface
    [Yanodesurf, dS(2)] = anodesurf(Yanode(end,:));
    
    %Procedure to find the activity at the start of the membrane
    lambda2 = 14;
    
    lambda1 = lambda2 - ((Const.twm*(Const.j/Const.F)-...
        Const.Jwm)*Const.Mm/(Const.Dm*Const.rodry))*Const.dm;
    
    a1 = activity(lambda1);

    for i = 1:length(a1)
       if a1(i) < 1
          a = a1(i);
       end
    end
    
    %Boundary conditions at the start of the membrane
    Tm0 = Yanodesurf(1);
    phim0 = Yanodesurf(2);
    am0 = a;
    Jqm0 = Yanodesurf(3);
    sm0 = Yanode(end,5)+dS(2);
    
    ym0 = [Tm0, phim0, am0, Jqm0, sm0];
    
    %Calculating the variations of the unknown parameters in the 
    %membrane
    [Xmembrane, Ymembrane] = ode15s('membrane',xmembrane,ym0);
    
    for k = 1:length(Xmembrane)
        chi(k) = Xi(Ymembrane(k,3));
    end
    
    %Calculating the jumps of the unknown parameters in the 
    %cathode surface
    [Ycatodesurf, dS(4)] = cathodesurf(Ymembrane(end,:));
    
    %Boundary conditions at the start of the cathode
    Tc0 = Ycatodesurf(1);
    phic0 = Ycatodesurf(2);
    Jqc0 = Ycatodesurf(3);
    xO20 = Const.xO20 - Const.j/(4*Const.F*Const.DON)*Const.ds;
    sc0 = Ymembrane(end,5)+dS(4);
    
    yc0 = [Tc0, phic0, xO20, Jqc0, sc0];
    
    %Calculating the variations of the unknown parameters in the 
    %cathode
    [Xcathode, Ycatode] = ode15s('Cathode',xcathode,yc0);
    
    Tc = Ycatode(end,1);
    phic = Ycatode(end,2);
    Jqc = Ycatode(end,4);
    
    %%%%Total energy balance%%%%%%
    
    Ein = Const.JH2*(Const.cph2*(Const.T0-Const.Tq))+...
        Const.Jwa*(Const.Hwgas+Const.cpwgas*...
       (Const.T0-Const.Tq))+Jqa0;
    
    Eut = Const.JO2*(Const.cpo2*(Tc-Const.Tq))+Const.Jwc*...
        (Const.Hwgas+Const.cpwgas*(Tc-Const.Tq))+Jqc+...
        Const.j*phic;
    
    res(1) = Eut - Ein;
    
    %%%%%%%%%%ENTROPY%%%%%%%%%%%%%%
    
    for i = 1:length(Xanode)
        [extra, sigma1(i)] = anode(Xanode(i), Yanode(i,:));
    end
    dS(1) = trapz(Xanode,sigma1)*(Const.ds);
    
    for i = 1:length(Xmembrane)
        [extra, sigma2(i)] = membrane(Xmembrane(i),...
            Ymembrane(i,:));
    end
    dS(3) = trapz(Xmembrane,sigma2)*(Const.ds+Const.dm);
    
    for i = 1:length(Xcathode)
        [extra, sigma3(i)] = Cathode(Xcathode(i), Ycatode(i,:));
    end
    dS(5) = trapz(Xcathode,sigma3)*(2*Const.ds+Const.dm);
    
    dStot = sum(dS);
    
    Xvector = [Xanode;Xmembrane;Xcathode];
    Yvector = [Yanode;Ymembrane;Ycatode];
    
    
    
    
    %%%%%%%%%%%%%%%%%%TOTAL ENTROPY BALANCE%%%%%%%%%%%
    
    Swc = Const.Swgas+Const.cpwgas*log(Tc/Const.Tq); 
    SO2 = Const.So2+Const.cpo2*log(Tc/Const.Tq)-Const.R*log(0.21); 
    Swa = Const.Swgas+Const.cpwgas*log(Const.T0/Const.Tq); 
    SH2 = Const.Sh2+Const.cph2*log(Const.T0/Const.Tq); 
    
    dStotal = (Jqc/Tc)-(Jqa0/Const.T0)+(Const.j/Const.F)*...
        (0.5*(Swc-SH2)-0.25*SO2)+Const.Jwa*(Swc-Swa);
    
    res(2) = dStotal - dStot;

    
    
       
    if plot == 1

        %Plotting the temperature profile through each segment
        
         figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xanode, Yanode(:,1));
        myfit2 = line([Xanode(end) Xanode(end)],...
            [Yanode(end,1) Yanodesurf(1)]);
        myfit3 = line(Xmembrane, Ymembrane(:,1));
        myfit4 = line([Xmembrane(end) Xmembrane(end)],...
            [Ymembrane(end,1) Ycatodesurf(1)]);
        myfit5 = line(Xcathode, Ycatode(:,1)); 
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{T} \rm{/ K}'                );
        xlim([0 xcathode(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
        set(myfit3                          , ...
        'LineWidth'       , 4           );
        set(myfit4                          , ...
        'LineWidth'       , 4           );
        set(myfit5                          , ...
        'LineWidth'       , 4           );
 
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );


        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
    
        %Plotting the mole fraction profile through anode and
        %cathode backing
    
         figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xanode, Yanode(:,3));
        myfit2 = line(Xcathode, Ycatode(:,3)); 
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{x}'                );
        xlim([0 xcathode(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );


    
        %Plotting the electrical potential profile through each segment

          figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xanode, Yanode(:,2));
        myfit2 = line([Xanode(end) Xanode(end)],...
            [Yanode(end,2) Yanodesurf(2)]);
        myfit3 = line(Xmembrane, Ymembrane(:,2));
        myfit4 = line([Xmembrane(end) Xmembrane(end)],...
            [Ymembrane(end,2) Ycatodesurf(2)]);
        myfit5 = line(Xcathode, Ycatode(:,2)); 
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{\phi} \rm{/ V}'                );
        xlim([0 xcathode(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
        set(myfit3                          , ...
        'LineWidth'       , 4           );
        set(myfit4                          , ...
        'LineWidth'       , 4           );
        set(myfit5                          , ...
        'LineWidth'       , 4           );

      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',45);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
        %Plotting the heat flux profile through each segment 
    
              figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xanode, Yanode(:,4));
        myfit2 = line([Xanode(end) Xanode(end)],...
            [Yanode(end,4) Yanodesurf(3)]);
        myfit3 = line(Xmembrane, Ymembrane(:,4));
        myfit4 = line([Xmembrane(end) Xmembrane(end)],...
            [Ymembrane(end,4) Ycatodesurf(3)]);
        myfit5 = line(Xcathode, Ycatode(:,4)); 
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{J_{q}^{}} \rm{/ W/m^{2}}'                );
        xlim([0 xcathode(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
        set(myfit3                          , ...
        'LineWidth'       , 4           );
        set(myfit4                          , ...
        'LineWidth'       , 4           );
        set(myfit5                          , ...
        'LineWidth'       , 4           );
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',50);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
      
        %Plotting the accumulated entropy production profile 
        %through each segment
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xanode, Yanode(:,5));
        myfit2 = line([Xanode(end) Xanode(end)],...
            [Yanode(end,5) Ymembrane(1,5)]);
        myfit3 = line(Xmembrane, Ymembrane(:,5));
        myfit4 = line([xmembrane(end) Xmembrane(end)],...
            [Ymembrane(end,5) Ycatode(1,5)]);
        myfit5 = line(Xcathode, Ycatode(:,5)); 
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{\sigma} \rm{/ W/K m^{2}}'                );
        xlim([0 xcathode(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );
        set(myfit2                          , ...
        'LineWidth'       , 4           );
        set(myfit3                          , ...
        'LineWidth'       , 4           );
        set(myfit4                          , ...
        'LineWidth'       , 4           );
        set(myfit5                          , ...
        'LineWidth'       , 4           );
      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',50);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
          
        %Plotting the water content in the membrane
    
                  figure('Units', 'pixels', ...
        'Position', [100 100 500 375]);
        hold on
        myfit1 = line(Xmembrane, chi);
        hXLabel = xlabel('\it{d} \rm{/ m}'                     );
        hYLabel = ylabel('\it{\chi} \rm{/ H_{2}O per sulfonic site}'                );
        xlim([Xanode(end),Xmembrane(end)])
        set(myfit1                          , ...
        'LineWidth'       , 4           );

      
         set( gca                       , ...
         'FontName'   , 'Helvetica', ...
         'FontSize',50);
         set([hXLabel, hYLabel], ...
         'FontName'   , 'AvantGarde');
         set([hXLabel, hYLabel]  , ...
         'FontSize'   , 45          );
     

        set(gca, ...
        'Box'         , 'off'     , ...
        'TickDir'     , 'out'     , ...
        'TickLength'  , [.04 .04] , ...
        'XMinorTick'  , 'on'      , ...
        'YMinorTick'  , 'on'      , ...
        'YGrid'       , 'on'      , ...
        'XColor'      , [.3 .3 .3], ...
        'YColor'      , [.3 .3 .3], ...
        'LineWidth'   , 1         );
    
    
    end
    
end